###############################################################################
#                                                                             #
# SalesforceConnector                                                         #
# Copyright(C), 2006, Plone Foundation - ALL RIGHTS RESERVED                  #
#                                                                             #
# This software is licensed under the Terms and Conditions contained within   #
# the License.txt file that accompanied this software.  Any inquiries         #
# concerning the scope or enforceability of the license should be addressed   #
# to:                                                                         #
#                                                                             #
# Plone Foundation                                                            #
# 4617 Montrose Blvd., Suite C215                                             #
# Houston, Texas 77006 USA                                                    #
# p. +1 713.942.2377 | f. +1 832.201.8856                                     #
# www.enfoldsystems.com                                                       #
# info@enfoldsystems.com                                                      #
#                                                                             #
###############################################################################


from zope.app.form.interfaces import WidgetInputError
from zope.formlib import form
from Products.Five.formlib import formbase
from Products.CMFCore.utils import getToolByName
from interfaces import IUserPropertiesEdit, IUserAdd
from config import field_mapping
from Products.Five.browser import pagetemplatefile

class UserEditForm(formbase.PageForm):

    form_fields = form.FormFields(IUserPropertiesEdit)

    @form.action('edit')
    def action_edit(self, action, data):
        mtool = getToolByName(self.context, 'portal_membership')
        member = mtool.getAuthenticatedMember()
        member.setProperties(**data)

    def setUpWidgets(self, ignore_request=False):
        mtool = getToolByName(self.context, 'portal_membership')
        member = mtool.getAuthenticatedMember()
        data = dict()
        for fname, fdata in field_mapping.items():
            default = fdata.get('default', None)
            value = member.getProperty(fname, default)
            if value is not None:
                data[fname] = value
        self.widgets = form.setUpWidgets(
                self.form_fields, self.prefix, self.context, self.request,
                data=data, ignore_request=ignore_request)

    def validate(self, action, data):
        rtool = getToolByName(self.context, 'portal_registration')
        errors = formbase.PageForm.validate(self, action, data)
        widgets = self.widgets
        email = data.get('email', '')
        if email:
            if not rtool.isValidEmail(email):
                email_error = 'Please enter a valid email.'
                errors.append(WidgetInputError('email', 'Email', email_error))
                widgets['email'].error = email_error
        return errors


class UserAddForm(formbase.PageForm):

    form_fields = form.FormFields(IUserAdd)

    registered_template = pagetemplatefile.ZopeTwoPageTemplateFile(
            'www/registered.pt')

    @form.action('submit')
    def action_submit(self, action, data):
        if 'confirm_password' in data:
            del data['confirm_password']
        rtool = getToolByName(self.context, 'portal_registration')
        id = data['username']
        password = data['password']
        props = data.copy()
        del props['password']
        member = rtool.addMember(id, password, properties=props)
        self.request.set('username', data['username'])
        self.request.set('password', data['password'])
        return self.registered_template()

    def validate(self, action, data):
        rtool = getToolByName(self.context, 'portal_registration')
        errors = formbase.PageForm.validate(self, action, data)
        widgets = self.widgets
        password = data.get('password', '')
        confirm = data.get('confirm_password', '')
        if password:
            passwd_error = rtool.testPasswordValidity(password, confirm=confirm)
            if passwd_error:
                errors.append(WidgetInputError('password', 'Password',
                        passwd_error))
                errors.append(WidgetInputError('confirm_password',
                        'Confirm Password', passwd_error))
                widgets['password'].error = passwd_error
                widgets['confirm_password'].error = passwd_error
        email = data.get('email', '')
        if email:
            if not rtool.isValidEmail(email):
                email_error = ('Please enter a valid email.')
                errors.append(WidgetInputError('email', 'Email', email_error))
                widgets['email'].error = email_error
        username = data.get('username', '')
        if username:
            if not rtool.isMemberIdAllowed(username):
                username_error = ('The username entered is either already in '
                        'use or invalid.')
                errors.append(WidgetInputError('username', 'User Name',
                        username_error))
                widgets['username'].error = username_error
        return errors

