###############################################################################
#                                                                             #
# SalesforceConnector                                                         #
# Copyright(C), 2006, Plone Foundation - ALL RIGHTS RESERVED                  #
#                                                                             #
# This software is licensed under the Terms and Conditions contained within   #
# the License.txt file that accompanied this software.  Any inquiries         #
# concerning the scope or enforceability of the license should be addressed   #
# to:                                                                         #
#                                                                             #
# Plone Foundation                                                            #
# 4617 Montrose Blvd., Suite C215                                             #
# Houston, Texas 77006 USA                                                    #
# p. +1 713.942.2377 | f. +1 832.201.8856                                     #
# www.enfoldsystems.com                                                       #
# info@enfoldsystems.com                                                      #
#                                                                             #
###############################################################################

from datetime import datetime
from Products.CMFPlone import PloneMessageFactory as _
from vocabularies import languages

# credentials_fields and field_mapping contain the information neccesary for
# retrieving data from Salesforce and using it in plone. Each entry can
# contain the following data:
#   field: This is the field name used by Salesforce. Salesforce adds '__c' to
#          the end of custom field names. If you omit that here it won't work.
#
#   required: Whether entry is required for the field.
#
#   max_length: Maximum length for value entered in a text field
#
#   label: Label used to display the field in plone. Must be a unicode string.
#
#   default: Default value for the field
#
#   type: This is the type of field to be used in plone. The accepted values
#         are:
#             string: A single line of text
#             text: Multiline text
#             boolean: True or False values(checkboxes)
#             date: Date values.
#             int: Integer numbers
#             float: Non-Integer numbers
#             lines: A list of strings

# credentials_fields mapping should always contain the username and password
# fields and only those fields. All other fields will be ignored.

credentials_fields = dict(
    username = dict(
            field='UserName__c',
            max_length=50,
            label=u'Username'),
    password = dict(
            field='Password__c',
            max_length=100,
            label=u'Password'),
    )

# the field_mapping mapping should always contain the fields below they are the
# fields required for Salesforce and Plone. You can add additional fields here
# and edit existing ones but you should not remove fields unless absolutely
# necessary. If you do add new fields they need to be added to field_order
# below. If you want a field from field_mapping to show up on the registration
# form you can add it to register_fields below.

field_mapping = dict(
    firstname = dict(
            field='FirstName',
            required=True,
            type='string',
            default='',
            label=u'First Name'),
    lastname = dict(
            field='LastName',
            required=True,
            type='string',
            default='',
            label=u'Last Name'),
    email = dict(
            field='Email',
            required=True,
            type='string',
            default='',
            label=u'Email'),
    language = dict(
            field='Language__c',
            required=False,
            type='string',
            default='',
            label=u'Language',
            vocabulary=languages),
    description = dict(
            field='Biography__c',
            required=False,
            type='text',
            default='',
            label=u'Biography',
            max_length=32000),
    home_page = dict(
            field='HomePage__c',
            required=False,
            type='string',
            default='',
            label=u'Home Page',
            max_length=255),
    wysiwyg_editor = dict(
            field='ContentEditor__c',
            required=False,
            type='string',
            default='Kupu',
            label=u'Content Editor',
            max_length=100),
    ext_editor = dict(
            field='ExternalEditor__c',
            type='boolean',
            default=False,
            label=u'External Editor'),
    listed = dict(
            field='Listed__c',
            type='boolean',
            default=False,
            label=u'Listed'),
    login_time = dict(
            field='LoginTime__c',
            required=False,
            type='date',
            default=datetime(2000, 1, 1),
            label=u'Login Time'),
    last_login_time = dict(
            field='LastLoginTime__c',
            required=False,
            type='date',
            default=datetime(2000, 1, 1),
            label=u'Last Login Time'),
    location = dict(
            field='Location__c',
            required=False,
            type='string',
            default='',
            label=u'Location',
            max_length=255),
#    accountid = dict(
#            field='AccountID',
#            required=False,
#            type='string',
#            default='00130000009wC1ZAAU',
#            label=u'Salesforce Account ID',
#            max_length=18),
    )

# field_order is the order fields are displayed on the user properties edit
# page. If you add new fields to field_mapping above they need to be added here
# as well.

field_order = ('firstname', 'lastname', 'email', 'location', 'language',
        'description', 'home_page', 'wysiwyg_editor', 'ext_editor', 'listed')

# register_fields is a list of fields from field_mapping that will be added to
# the registration page along with username and password.

register_fields = ('firstname', 'lastname', 'email',)

# fullname_format is used to format the fullname for display in plone. I don't
# think it is working at the moment.
fullname_format = '%(firstname)s %(lastname)s'

# do not change this
USERNAME_FIELD = credentials_fields['username']['field']
PASSWD_FIELD = credentials_fields['password']['field']
