###############################################################################
#                                                                             #
# SalesforceConnector                                                         #
# Copyright(C), 2006, Plone Foundation - ALL RIGHTS RESERVED                  #
#                                                                             #
# This software is licensed under the Terms and Conditions contained within   #
# the License.txt file that accompanied this software.  Any inquiries         #
# concerning the scope or enforceability of the license should be addressed   #
# to:                                                                         #
#                                                                             #
# Plone Foundation                                                            #
# 4617 Montrose Blvd., Suite C215                                             #
# Houston, Texas 77006 USA                                                    #
# p. +1 713.942.2377 | f. +1 832.201.8856                                     #
# www.enfoldsystems.com                                                       #
# info@enfoldsystems.com                                                      #
#                                                                             #
###############################################################################

from zope import interface, schema
from config import field_mapping, field_order, register_fields
from config import credentials_fields
from zope.interface.interface import InterfaceClass

field_factories = dict(
    string=schema.TextLine,
    boolean=schema.Bool,
    text=schema.Text,
    date=schema.Date,
    int=schema.Int,
    long=schema.Int,
    float=schema.Float,
    lines=schema.List,
    )
fields = dict()
for fname in field_order:
    fdata = field_mapping[fname]
    vocabulary = fdata.get('vocabulary', None)
    if vocabulary is not None:
        field = schema.Choice(vocabulary=vocabulary,
                required=fdata.get('required', False),
                title=fdata.get('label', unicode(fname).title()),
                description=fdata.get('description', u'')
                )
    else:
        factory = field_factories[fdata['type']]
        kw = dict(
            required=fdata.get('required', False),
            title=fdata.get('label', u''),
            description=fdata.get('description', u'')
            )
        max_length = fdata.get('max_length', None)
        if max_length is not None:
            kw['max_length'] = max_length
        field = factory(**kw)
    fields[fname] = field

IUserPropertiesEdit = InterfaceClass('IUserPropertiesEdit',
    bases=(interface.Interface,), attrs=fields)

reg_fields = dict()
for fname in ('username', 'password'):
    if fname == 'username':
        factory = schema.TextLine
        default_title = u'Username'
    elif fname == 'password':
        factory = schema.Password
        default_title = u'Password'
    fdata = credentials_fields[fname]
    kw = dict(title=fdata.get('label', default_title),
            required=True
            )
    max_length = fdata.get('max_length', None)
    if max_length is not None:
        kw['max_length'] = max_length
    reg_fields[fname] = factory(**kw)

passwd_data = credentials_fields['password']
passwd_label = passwd_data.get('label', 'Password')
confirm_label = 'Confirm %s' % passwd_label
passwd_max_length = passwd_data.get('max_length', None)
reg_fields['confirm_password'] = schema.Password(title=confirm_label,
        required=True, max_length=passwd_max_length)

for fname in register_fields:
    reg_fields[fname] = fields[fname]

IUserAdd = InterfaceClass('IUserAdd', bases=(interface.Interface,),
        attrs=reg_fields)
